==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer.md <==
# ElasticBeanstalkContainer


```text
aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer
```

```text
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')
```



| Illustration | ElasticBeanstalkContainer | ElasticBeanstalkContainerCard | ElasticBeanstalkContainerGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer.png) | ![illustration for ElasticBeanstalkContainer](../../../aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer.Local.png) | ![illustration for ElasticBeanstalkContainerCard](../../../aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainerCard.Local.png) | ![illustration for ElasticBeanstalkContainerGroup](../../../aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainerGroup.Local.png) |




## ElasticBeanstalkContainer

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainer
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainer('ElasticBeanstalkContainer', 'Elastic Beanstalk Container', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainer
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainer('ElasticBeanstalkContainer', 'Elastic Beanstalk Container', 'an optional tech label')
@enduml
```

## ElasticBeanstalkContainerCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainerCard
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainerCard('ElasticBeanstalkContainerCard', 'Elastic Beanstalk Container Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainerCard
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainerCard('ElasticBeanstalkContainerCard', 'Elastic Beanstalk Container Card', 'an optional description')
@enduml
```

## ElasticBeanstalkContainerGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainerGroup
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainerGroup('ElasticBeanstalkContainerGroup', 'Elastic Beanstalk Container Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainerGroup
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainerGroup('ElasticBeanstalkContainerGroup', 'Elastic Beanstalk Container Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer.md <==
# ElasticBeanstalkContainer


```text
aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer
```

```text
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')
```



| Illustration | ElasticBeanstalkContainer | ElasticBeanstalkContainerCard | ElasticBeanstalkContainerGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer.png) | ![illustration for ElasticBeanstalkContainer](../../../aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer.Local.png) | ![illustration for ElasticBeanstalkContainerCard](../../../aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainerCard.Local.png) | ![illustration for ElasticBeanstalkContainerGroup](../../../aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainerGroup.Local.png) |




## ElasticBeanstalkContainer

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainer
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainer('ElasticBeanstalkContainer', 'Elastic Beanstalk Container', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainer
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainer('ElasticBeanstalkContainer', 'Elastic Beanstalk Container', 'an optional tech label')
@enduml
```

## ElasticBeanstalkContainerCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainerCard
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainerCard('ElasticBeanstalkContainerCard', 'Elastic Beanstalk Container Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainerCard
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainerCard('ElasticBeanstalkContainerCard', 'Elastic Beanstalk Container Card', 'an optional description')
@enduml
```

## ElasticBeanstalkContainerGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainerGroup
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainerGroup('ElasticBeanstalkContainerGroup', 'Elastic Beanstalk Container Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element ElasticBeanstalkContainerGroup
include('aws-q3-2021/Resource/GroupIcons/ElasticBeanstalkContainer')

' renders the element
ElasticBeanstalkContainerGroup('ElasticBeanstalkContainerGroup', 'Elastic Beanstalk Container Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
